

use "Data/Workfile.dta", clear


*Aspirationen - real*
recode t31135a (1 2 4 = 0 "Other") (3 = 1 "HEE"), gen(temp1)
tab t31135a temp1, miss
recode t31135c (1 2 3 4 7 = 0 "Other") (5 6 = 1 "HEE"), gen(temp2)
tab t31135c temp2, miss

gen aspi_real = .
replace aspi_real = temp1
replace aspi_real = temp2 if missing(aspi_real) & !missing(temp2)
label var aspi_real "Real. aspirations for HEE"
fre aspi_real
drop temp1 temp2


*Aspirationen - ideal*
recode t31035a (1 2 4 = 0 "Other") (3 = 1 "HEE"), gen(temp1)
tab t31035a temp1, miss
recode t31035c (1 2 3 4 7 = 0 "Other") (5 6 = 1 "HEE"), gen(temp2)
tab t31035c temp2, miss

gen aspi_ideal = .
replace aspi_ideal = temp1
replace aspi_ideal = temp2 if missing(aspi_ideal) & !missing(temp2)
label var aspi_ideal "Ideal. aspirations for HEE"
fre aspi_ideal
drop temp1 temp2


*Bildungsabschluss der Eltern*
bysort ID_t: egen temp1 = max(p731802_g2)
bysort ID_t: egen temp2 = max(p731852_g2)
egen temp3 = rowmax(temp1 temp2)
recode temp3 (0 1 2 3 4 = 0 "Max. Intermediate") (5 6 = 1 "HEE") (7 8 = 2 "Tertiary") ///
	, gen(pareduc)
label var pareduc "Parental education"
fre pareduc
drop temp1 temp2 temp3


*EGP der Eltern*
foreach VAR of varlist t731403_g8 t731453_g8 t731413_g8 ///
	t731463_g8 p731904_g8 p731954_g8 {
			recode `VAR' (1 2 = 2 "Service") (3 5 6 7 8 = 1 "Intermediate") ///
				(4 9 10 11 = 0 "Working"), gen(`VAR'R)
}
bysort ID_t: egen temp1 = max(p731904_g8R)
bysort ID_t: egen temp2 = max(p731954_g8R)

egen egp = rowmax(temp1 temp2)
label var egp "Parental EGP"
label values egp p731904_g8R
drop temp1 temp2
fre egp if wave == 1		


*Aktuell auf dem Gymnasium
recode tx80232 (7 = 1 "Gym") (1 2 3 4 5 6 8 10 = 0 "Sonstiges") (9 = .k), gen(temp1)
tab tx80232 temp1, miss

recode t723080_g1 (9 = 1 "Gym") ///
	(3 4 5 6 7 8 11 14 15 12 13 17 = 0 "Sonstiges") (1 2 10 = .k), gen(temp2)
tab t723080_g1 temp2, miss

recode tf11404 (8 = 1 "Gym") (4 5 6 10 11 13 14 = 0 "Sonstiges") (12 = .k), gen(temp3)
tab tf11404 temp3, miss

recode tf11405 (11 12 14 15 19 20 = 1 "Gym") ///
	(1 2 5 7 8 9 10 16 17 18 21 22 23 24 25 26 27 28 30 31 = 0 "Sonstiges"), gen(temp4)
tab tf11405 temp4, miss

gen gym = .
replace gym = temp1 if missing(gym) & !missing(temp1)
replace gym = temp2 if missing(gym) & !missing(temp2)
replace gym = temp3 if missing(gym) & !missing(temp3)
replace gym = temp4 if missing(gym) & !missing(temp4)
drop temp1 temp2 temp3 temp4
label define gym 0 "Other" 1 "Academic", replace
label values gym gym
fre gym
label var gym "Attending the academic track"
bysort wave: sum gym


*Teilnahme in W1, W2 und W5*
cap drop temp
bysort ID_t (wave): gen temp = 1 if wave == 1 & tx80220 == 1 & ///
	tx80220[_n+1] == 1 & tx80220[_n+4] == 1
replace temp = 0 if missing(temp)
list ID_t wave tx80220 temp in 1/100, sepby(ID_t)
bysort ID_t: egen alleteilnahmen = max(temp)
label var alleteilnahmen "Teilnahme in W1, W2 und W5"
drop temp


*Gleicher Schultyp in W1, W2 und W5*
cap drop temp
bysort ID_t (wave): gen temp = 1 if wave == 1 & !missing(gym) & gym == gym[_n+1] ///
	& gym == gym[_n+4]
replace temp = 0 if missing(temp)
list ID_t wave gym temp in 1/100, sepby(ID_t)
bysort ID_t: egen sameschool = max(temp)
label var sameschool "Gleicher Schultyp in W1, W2 und W5"
drop temp


*Geschlecht*
gen temp = tx80501 - 1
bysort ID_t: egen female = max(temp)
label var female "Female"
drop temp


*Migrationshintergrund*
bysort ID_t: egen temp1 = max(t400090_g1D)
bysort ID_t: egen temp2 = max(t400070_g1D)
gen migration = .
replace migration = 0 if temp1 == 0 & temp2 == 0
replace migration = 2 if temp1 == 1 & temp2 == 1
replace migration = 1 if !missing(temp1) & !missing(temp2) & missing(migration)
label define migration 0 "Both parents born in Germany" ///
	1 "One parent born abroad" 2 "Both parents born abroad"
label values migration migration
fre migration
drop temp1 temp2


*Einkommen der Eltern*
bysort ID_t (wave): egen einkommen = median(p510005)
gen logeinkommen = log(einkommen)


*Alter 2011*
gen temp = (mdy(1, 1, 2011) - mdy(tx8050m, 1, tx8050y)) / 365
bysort ID_t: egen alter2011 = max(temp)
sum alter2011, det
label var alter2011 "Age in 2011"
drop temp


*Zusammenleben der Eltern*
recode p731110 (1 6 = 1 "Zusammen") (2 3 4 5 = 0 "Alleine"), gen(temp)
bysort ID_t: egen zusammenleben = mode(temp), minmode
tab temp zusammenleben, miss
drop temp
label var zusammenleben "Parents living together"
fre zusammenleben


*Ost / West*
bysort ID_t: egen temp = mode(tx80109_g1), maxmode
recode temp (1 = 0 "West") (2 = 1 "East"), gen(osten)
label var osten "Living in eastern Germany"
fre osten
drop temp


*Schulform K5*
gen temp = tx80106 if wave == 1
replace temp = .k if inlist(temp, 1, 7)		//Grundschule, FS raus
replace temp = 0 if inlist(temp, 2, 3, 4, 5)
replace temp = 1 if inlist(temp, 6)
tab tx80106 temp, miss
bysort ID_t: egen schulform5 = max(temp)
label define schulform5 0 "Other" 1 "Academic"
label values schulform5 schulform5
fre schulform5
drop temp


*Leistung*
gen leistung = .
replace leistung = (math + read) / 2
replace leistung = math if missing(leistung) & !missing(math)
replace leistung = read if missing(leistung) & !missing(read)
*Interpolation for Wave 2*
bysort ID_t (wave): replace leistung = (leistung[_n-1] + leistung[_n+1]) / 2 ///
	if wave == 2
bysort wave: sum leistung
sort ID_t wave
list ID_t wave leistung math read in 1/200, sepby(ID_t)

cap drop temp
gen temp = leistung if wave == 1
bysort ID_t: egen leistung5 = max(temp)
drop temp
label var leistung5 "Leistung in K5"
sum leistung5 if wave == 1

bysort ID_t: egen score5 = max(dgcfsum)
label var score5 "Ability score (W1)"

bysort ID_t: egen speed5 = max(dgcfspeed)
label var speed5 "Ability speed (W1)"

gen temp = math if wave == 1
bysort ID_t: egen math5 = max(temp)
drop temp

gen temp = read if wave == 1
bysort ID_t: egen read5 = max(temp)
drop temp

label var math "Math competence"
label var read "Reading competence"

*** Relative Leistung ***
*https://www.stata.com/support/faqs/statistics/percentile-ranks-and-plotting-positions/
bysort wave: egen n = count(leistung) if inlist(wave, 1, 2, 5)
bysort wave: egen i = rank(leistung) if inlist(wave, 1, 2, 5), track
gen pcrank = ((i - 1) / (n - 1)) * 100	
drop i n

preserve
keep ID_t wave pcrank
reshape wide pcrank, i(ID_t) j(wave)
gen rankchange = pcrank5 - pcrank1
label var rankchange "Change in percentiles from grade 5 to 9"
keep ID_t rankchange
tempfile a
save `a'
restore
merge m:1 ID_t using `a', nogen


*** Mediationsvariablen generieren ***
recode pareduc (0 1 = 0 "Below tertiary") (2 = 1 "Tertiary"), gen(highedu)
recode migration (0 = 0) (1 2 = 1), gen(mig)


*Education*
cap drop temp
bysort ID_i: egen temp = mean(highedu) if wave == 1
bysort ID_t: egen mean_highedu = max(temp)
label var mean_highedu "Average share high educated parents per school (W1)"
drop temp

*Aspirationen*
cap drop temp
bysort ID_i: egen temp = mean(aspi_ideal) if wave == 1
bysort ID_t: egen mean_aspi = max(temp)
label var mean_aspi "Average share high aspirations per school (W1)"
drop temp

*Leistung*
cap drop temp
bysort ID_i: egen temp = mean(leistung) if wave == 1
bysort ID_t: egen mean_leistung = max(temp)
label var mean_leistung "Average competences per school (W1)"
drop temp



/*
bysort ID_i wave: egen mean_highedu = mean(highedu)
bysort ID_i wave: egen mean_mig = mean(mig)
bysort ID_i wave: egen mean_aspi = mean(aspi_ideal)
bysort ID_i wave: egen mean_leistung = mean(leistung)


*Income*
cap drop temp
bysort ID_i: egen temp = mean(logeinkommen) if wave == 1
bysort ID_t: egen mean_income = max(temp)
label var mean_income "Average income per school (G5)"
drop temp


*Migration*
cap drop temp
bysort ID_i: egen temp = mean(mig) if wave == 1
bysort ID_t: egen mean_mig = max(temp)
label var mean_income "Average share migrant background per school (G5)"
drop temp
